package com.ruoyi.basetyre.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.basetyre.domain.BaseCarQueue;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.basetyre.service.IBaseCarQueueService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 车队信息管理Controller
 * 
 * @author Yangwl
 * @date 2023-02-08
 */
@RestController
@RequestMapping("/carqueue/carqueue")
public class BaseCarQueueController extends BaseController
{
    @Autowired
    private IBaseCarQueueService baseCarQueueService;

    /**
     * 查询车队信息管理列表
     */
    @PreAuthorize("@ss.hasPermi('carqueue:carqueue:list')")
    @GetMapping("/list")
    public TableDataInfo list(BaseCarQueue baseCarQueue)
    {
        startPage();
        List<BaseCarQueue> list = baseCarQueueService.selectBaseCarQueueList(baseCarQueue);
        return getDataTable(list);
    }

    /**
     * 导出车队信息管理列表
     */
    @PreAuthorize("@ss.hasPermi('carqueue:carqueue:export')")
    @Log(title = "车队信息管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BaseCarQueue baseCarQueue)
    {
        List<BaseCarQueue> list = baseCarQueueService.selectBaseCarQueueList(baseCarQueue);
        ExcelUtil<BaseCarQueue> util = new ExcelUtil<BaseCarQueue>(BaseCarQueue.class);
        util.exportExcel(response, list, "车队信息管理数据");
    }

    /**
     * 获取车队信息管理详细信息
     */
    @PreAuthorize("@ss.hasPermi('carqueue:carqueue:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id)
    {
        return success(baseCarQueueService.selectBaseCarQueueById(id));
    }

    /**
     * 新增车队信息管理
     */
    @PreAuthorize("@ss.hasPermi('carqueue:carqueue:add')")
    @Log(title = "车队信息管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BaseCarQueue baseCarQueue)
    {
        return toAjax(baseCarQueueService.insertBaseCarQueue(baseCarQueue));
    }

    /**
     * 修改车队信息管理
     */
    @PreAuthorize("@ss.hasPermi('carqueue:carqueue:edit')")
    @Log(title = "车队信息管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BaseCarQueue baseCarQueue)
    {
        return toAjax(baseCarQueueService.updateBaseCarQueue(baseCarQueue));
    }

    /**
     * 删除车队信息管理
     */
    @PreAuthorize("@ss.hasPermi('carqueue:carqueue:remove')")
    @Log(title = "车队信息管理", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids)
    {
        return toAjax(baseCarQueueService.deleteBaseCarQueueByIds(ids));
    }
}
