package com.ruoyi.basetyre.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.basetyre.domain.BaseCarType;
import com.ruoyi.basetyre.service.IBaseCarTypeService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 车辆类型Controller
 * 
 * @author Yangwl
 * @date 2023-02-08
 */
@RestController
@RequestMapping("/cartype/cartype")
public class BaseCarTypeController extends BaseController
{
    @Autowired
    private IBaseCarTypeService baseCarTypeService;

    /**
     * 查询车辆类型列表
     */
    @PreAuthorize("@ss.hasPermi('cartype:cartype:list')")
    @GetMapping("/list")
    public TableDataInfo list(BaseCarType baseCarType)
    {
        startPage();
        List<BaseCarType> list = baseCarTypeService.selectBaseCarTypeList(baseCarType);
        return getDataTable(list);
    }

    /**
     * 导出车辆类型列表
     */
    @PreAuthorize("@ss.hasPermi('cartype:cartype:export')")
    @Log(title = "车辆类型", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BaseCarType baseCarType)
    {
        List<BaseCarType> list = baseCarTypeService.selectBaseCarTypeList(baseCarType);
        ExcelUtil<BaseCarType> util = new ExcelUtil<BaseCarType>(BaseCarType.class);
        util.exportExcel(response, list, "车辆类型数据");
    }

    /**
     * 获取车辆类型详细信息
     */
    @PreAuthorize("@ss.hasPermi('cartype:cartype:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id)
    {
        return success(baseCarTypeService.selectBaseCarTypeById(id));
    }

    /**
     * 新增车辆类型
     */
    @PreAuthorize("@ss.hasPermi('cartype:cartype:add')")
    @Log(title = "车辆类型", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BaseCarType baseCarType)
    {
        return toAjax(baseCarTypeService.insertBaseCarType(baseCarType));
    }

    /**
     * 修改车辆类型
     */
    @PreAuthorize("@ss.hasPermi('cartype:cartype:edit')")
    @Log(title = "车辆类型", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BaseCarType baseCarType)
    {
        return toAjax(baseCarTypeService.updateBaseCarType(baseCarType));
    }

    /**
     * 删除车辆类型
     */
    @PreAuthorize("@ss.hasPermi('cartype:cartype:remove')")
    @Log(title = "车辆类型", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids)
    {
        return toAjax(baseCarTypeService.deleteBaseCarTypeByIds(ids));
    }
}
