package com.ruoyi.basetyre.service.impl;

import java.util.List;
import java.util.UUID;

import com.ruoyi.basetyre.domain.BaseCarQueue;
import com.ruoyi.common.core.domain.model.LoginUser;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.basetyre.mapper.BaseCarQueueMapper;
import com.ruoyi.basetyre.service.IBaseCarQueueService;

/**
 * 车队信息管理Service业务层处理
 * 
 * @author Yangwl
 * @date 2023-02-08
 */
@Service
public class BaseCarQueueServiceImpl implements IBaseCarQueueService 
{
    @Autowired
    private BaseCarQueueMapper baseCarQueueMapper;

    /**
     * 查询车队信息管理
     * 
     * @param id 车队信息管理主键
     * @return 车队信息管理
     */
    @Override
    public BaseCarQueue selectBaseCarQueueById(String id)
    {
        return baseCarQueueMapper.selectBaseCarQueueById(id);
    }

    /**
     * 查询车队信息管理列表
     * 
     * @param baseCarQueue 车队信息管理
     * @return 车队信息管理
     */
    @Override
    public List<BaseCarQueue> selectBaseCarQueueList(BaseCarQueue baseCarQueue)
    {
        return baseCarQueueMapper.selectBaseCarQueueList(baseCarQueue);
    }

    /**
     * 新增车队信息管理
     * 
     * @param baseCarQueue 车队信息管理
     * @return 结果
     */
    @Override
    public int insertBaseCarQueue(BaseCarQueue baseCarQueue)
    {
        baseCarQueue.setCreateTime(DateUtils.getNowDate());
        baseCarQueue.setId(UUID.randomUUID().toString());
        LoginUser loginUser= SecurityUtils.getLoginUser();
        baseCarQueue.setCreateBy(loginUser.getUserId().toString());
        baseCarQueue.setCreateName(loginUser.getUsername());
        baseCarQueue.setModifyBy(loginUser.getUserId().toString());
        baseCarQueue.setModifyTime(DateUtils.getNowDate());
        return baseCarQueueMapper.insertBaseCarQueue(baseCarQueue);
    }

    /**
     * 修改车队信息管理
     * 
     * @param baseCarQueue 车队信息管理
     * @return 结果
     */
    @Override
    public int updateBaseCarQueue(BaseCarQueue baseCarQueue)
    {
        return baseCarQueueMapper.updateBaseCarQueue(baseCarQueue);
    }

    /**
     * 批量删除车队信息管理
     * 
     * @param ids 需要删除的车队信息管理主键
     * @return 结果
     */
    @Override
    public int deleteBaseCarQueueByIds(String[] ids)
    {
        return baseCarQueueMapper.deleteBaseCarQueueByIds(ids);
    }

    /**
     * 删除车队信息管理信息
     * 
     * @param id 车队信息管理主键
     * @return 结果
     */
    @Override
    public int deleteBaseCarQueueById(String id)
    {
        return baseCarQueueMapper.deleteBaseCarQueueById(id);
    }
}
