package com.ruoyi.basetyre.service.impl;

import java.util.List;
import java.util.UUID;

import com.ruoyi.common.core.domain.model.LoginUser;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.basetyre.mapper.BaseCarTypeMapper;
import com.ruoyi.basetyre.domain.BaseCarType;
import com.ruoyi.basetyre.service.IBaseCarTypeService;

/**
 * 车辆类型Service业务层处理
 * 
 * @author Yangwl
 * @date 2023-02-08
 */
@Service
public class BaseCarTypeServiceImpl implements IBaseCarTypeService 
{
    @Autowired
    private BaseCarTypeMapper baseCarTypeMapper;

    /**
     * 查询车辆类型
     * 
     * @param id 车辆类型主键
     * @return 车辆类型
     */
    @Override
    public BaseCarType selectBaseCarTypeById(String id)
    {
        return baseCarTypeMapper.selectBaseCarTypeById(id);
    }

    /**
     * 查询车辆类型列表
     * 
     * @param baseCarType 车辆类型
     * @return 车辆类型
     */
    @Override
    public List<BaseCarType> selectBaseCarTypeList(BaseCarType baseCarType)
    {
        return baseCarTypeMapper.selectBaseCarTypeList(baseCarType);
    }

    /**
     * 新增车辆类型
     * 
     * @param baseCarType 车辆类型
     * @return 结果
     */
    @Override
    public int insertBaseCarType(BaseCarType baseCarType)
    {
        baseCarType.setCreateTime(DateUtils.getNowDate());
        baseCarType.setId(UUID.randomUUID().toString());
        LoginUser loginUser= SecurityUtils.getLoginUser();
        baseCarType.setCreateBy(loginUser.getUserId().toString());
        baseCarType.setCreateName(loginUser.getUsername());
        baseCarType.setModifyBy(loginUser.getUserId().toString());
        baseCarType.setModifyTime(DateUtils.getNowDate());
        return baseCarTypeMapper.insertBaseCarType(baseCarType);
    }

    /**
     * 修改车辆类型
     * 
     * @param baseCarType 车辆类型
     * @return 结果
     */
    @Override
    public int updateBaseCarType(BaseCarType baseCarType)
    {
        return baseCarTypeMapper.updateBaseCarType(baseCarType);
    }

    /**
     * 批量删除车辆类型
     * 
     * @param ids 需要删除的车辆类型主键
     * @return 结果
     */
    @Override
    public int deleteBaseCarTypeByIds(String[] ids)
    {
        return baseCarTypeMapper.deleteBaseCarTypeByIds(ids);
    }

    /**
     * 删除车辆类型信息
     * 
     * @param id 车辆类型主键
     * @return 结果
     */
    @Override
    public int deleteBaseCarTypeById(String id)
    {
        return baseCarTypeMapper.deleteBaseCarTypeById(id);
    }
}
